Class: TurboDesktop::PathConfigurationsController
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- TurboDesktop::PathConfigurationsController
- Defined in:
- app/controllers/turbo_desktop/path_configurations_controller.rb
Instance Method Summary collapse
-
#show ⇒ Object
GET /turbo-desktop/path-configuration.json.
Instance Method Details
#show ⇒ Object
GET /turbo-desktop/path-configuration.json
Returns the path configuration JSON that the desktop app uses to determine how to present each URL (default, modal, new window, native).
This endpoint mirrors the pattern used by Hotwire Native mobile apps.
9 10 11 |
# File 'app/controllers/turbo_desktop/path_configurations_controller.rb', line 9 def show render json: TurboDesktop.configuration.path_configuration end |